Summary:	Initramfs generator using udev
Name:		dracut
Version:	023
Release:	1
License:	GPL v2+
Group:		Base
Source0:	ftp://www.kernel.org/pub/linux/utils/boot/dracut/%{name}-%{version}.tar.xz
# Source0-md5:	7ae42fa8272363400ee6161c47d1beb5
Source1:	pld.conf
Patch0:		no-rh.patch
Patch1:		bash-sh.patch
Patch2:		plymouth-libexec.patch
Patch4:		os-release.patch
Patch5:		plymouth-logo.patch
URL:		https://dracut.wiki.kernel.org/
BuildRequires:	dash
BuildRequires:	docbook-dtd45-xml
BuildRequires:	docbook-style-xsl
BuildRequires:	libxslt-progs
Requires:	bash
Requires:	coreutils
Requires:	cpio
Requires:	filesystem
Requires:	findutils
Requires:	glibc-misc
Requires:	grep
Requires:	gzip
Requires:	hardlink
Requires:	sed
Requires:	systemd-units
Requires:	udev
Requires:	util-linux >= 2.20
Requires:	vim-rt
Requires:	vim-static
Requires:	virtual(module-tools)
# disabled due to angry (bug)reports, because it changes well known
# net device names from ethX to emX or pXpY
#Suggests:	biosdevname
Suggests:	btrfs-progs
Suggests:	busybox
Suggests:	bzip2
Suggests:	cryptsetup
Suggests:	dash
Suggests:	device-mapper
Suggests:	dmraid
Suggests:	e2fsprogs
Suggests:	gnupg
Suggests:	kbd
Suggests:	keyutils
Suggests:	libselinux-utils
Suggests:	losetup
Suggests:	lvm2
Suggests:	mdadm
Suggests:	multipath-tools
Suggests:	plymouth
Suggests:	suspend-utils
Suggests:	syslogdaemon
Suggests:	xfsprogs
Suggests:	xz
Conflicts:	kmod < 6
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		dracutlibdir	%{_prefix}/lib/dracut

%description
Dracut contains tools to create a bootable initramfs for 2.6 Linux
kernels. Unlike existing implementations, dracut does hard-code as
little as possible into the initramfs. Dracut contains various modules
which are driven by the event-based udev. Having root on MD, DM, LVM2,
LUKS is supported as well as NFS, iSCSI, NBD, FCoE with the
dracut-network package.

%package network
Summary:	Dracut modules to build a dracut initramfs with network support
Group:		Base
Requires:	%{name} = %{version}-%{release}
Requires:	bridge-utils
Requires:	dhcp-client
Requires:	iproute2
Requires:	iputils-arping
Requires:	iputils-ping
Requires:	nbd
Requires:	net-tools
Requires:	nfs-utils-clients
Requires:	open-iscsi
Requires:	openssh-clients
Requires:	rpcbind
Suggests:	curl

%description network
This package requires everything which is needed to build a generic
all purpose initramfs with network support with dracut.

%package fips
Summary:	Dracut modules to build a dracut initramfs with an integrity check
Group:		Base
Requires:	%{name} = %{version}-%{release}
Requires:	hmaccalc
Requires:	nss-softokn-freebl

%description fips
This package requires everything which is needed to build an all
purpose initramfs with dracut, which does an integrity check.

%package fips-aesni
Summary:	Dracut modules to build a dracut initramfs with an integrity check with aesni-intel
Group:		Base
Requires:	%{name}-fips = %{version}-%{release}

%description fips-aesni
This package requires everything which is needed to build an all
purpose initramfs with dracut, which does an integrity check and adds
the aesni-intel kernel module.

%package caps
Summary:	Dracut modules to build a dracut initramfs which drops capabilities
Group:		Base
Requires:	%{name} = %{version}-%{release}
Requires:	libcap

%description caps
This package requires everything which is needed to build an all
purpose initramfs with dracut, which drops capabilities.

%package tools
Summary:	Dracut tools to build the local initramfs
Group:		Base
Requires:	%{name} = %{version}-%{release}

%description tools
This package contains tools to assemble the local initrd and host
configuration.

%prep
%setup -q
#%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch4 -p1
%patch5 -p1

%{__sed} -i -e 's,@lib@,%{_lib},g' modules.d/50plymouth/module-setup.sh

%build
%{__make}

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{/boot/dracut,/etc/logrotate.d,/sbin} \
	$RPM_BUILD_ROOT/var/{log,lib/{dracut/overlay,initramfs}}

%{__make} install DESTDIR=$RPM_BUILD_ROOT \
	libdir=%{_prefix}/lib \
	bindir=%{_bindir} \
	systemdsystemunitdir=%{systemdunitdir} \
	sysconfdir=%{_sysconfdir} \
	mandir=%{_mandir}

install -p %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/dracut.conf.d/01-dist.conf
install -p dracut.conf.d/fips.conf.example $RPM_BUILD_ROOT%{_sysconfdir}/dracut.conf.d/40-fips.conf
install -p dracut.logrotate $RPM_BUILD_ROOT/etc/logrotate.d/dracut_log

# create compat symlink
ln -s %{_bindir}/dracut $RPM_BUILD_ROOT/sbin/dracut

# remove gentoo specific modules
%{__rm} -r $RPM_BUILD_ROOT/%{dracutlibdir}/modules.d/50gensplash

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
%doc README HACKING TODO COPYING AUTHORS NEWS dracut.html dracut.png dracut.svg
%dir %{_sysconfdir}/dracut.conf.d
%config(noreplace) %{_sysconfdir}/dracut.conf
%config(noreplace) %{_sysconfdir}/dracut.conf.d/01-dist.conf
%config(noreplace) /etc/logrotate.d/dracut_log
# compat symlink
%attr(755,root,root) /sbin/dracut
%attr(755,root,root) %{_bindir}/dracut
%attr(755,root,root) %{dracutlibdir}/dracut-install
%attr(755,root,root) %{_bindir}/mkinitrd
%attr(755,root,root) %{_bindir}/lsinitrd
%dir %{dracutlibdir}
%dir %{dracutlibdir}/modules.d
%attr(755,root,root) %{dracutlibdir}/dracut-functions.sh
%attr(755,root,root) %{dracutlibdir}/dracut-functions
%attr(755,root,root) %{dracutlibdir}/dracut-logger.sh
%attr(755,root,root) %{dracutlibdir}/dracut-initramfs-restore
%dir %{dracutlibdir}/modules.d/00bootchart
%attr(755,root,root) %{dracutlibdir}/modules.d/00bootchart/*.sh
%dir %{dracutlibdir}/modules.d/00dash
%attr(755,root,root) %{dracutlibdir}/modules.d/00dash/*.sh
%dir %{dracutlibdir}/modules.d/01bash
%attr(755,root,root) %{dracutlibdir}/modules.d/01bash/*.sh
%dir %{dracutlibdir}/modules.d/04watchdog
%attr(755,root,root) %{dracutlibdir}/modules.d/04watchdog/*.sh
%dir %{dracutlibdir}/modules.d/05busybox
%attr(755,root,root) %{dracutlibdir}/modules.d/05busybox/*.sh
%dir %{dracutlibdir}/modules.d/10i18n
%{dracutlibdir}/modules.d/10i18n/README
%{dracutlibdir}/modules.d/10i18n/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/10i18n/*.sh
%dir %{dracutlibdir}/modules.d/30convertfs
%attr(755,root,root) %{dracutlibdir}/modules.d/30convertfs/*.sh
%dir %{dracutlibdir}/modules.d/50plymouth
%attr(755,root,root) %{dracutlibdir}/modules.d/50plymouth/*.sh
%dir %{dracutlibdir}/modules.d/80cms
%attr(755,root,root) %{dracutlibdir}/modules.d/80cms/*.sh
%dir %{dracutlibdir}/modules.d/90btrfs
%{dracutlibdir}/modules.d/90btrfs/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/90btrfs/*.sh
%dir %{dracutlibdir}/modules.d/90crypt
%attr(755,root,root) %{dracutlibdir}/modules.d/90crypt/*.sh
%dir %{dracutlibdir}/modules.d/91crypt-loop
%attr(755,root,root) %{dracutlibdir}/modules.d/91crypt-loop/*.sh
%dir %{dracutlibdir}/modules.d/90dm
%{dracutlibdir}/modules.d/90dm/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/90dm/*.sh
%dir %{dracutlibdir}/modules.d/90dmraid
%{dracutlibdir}/modules.d/90dmraid/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/90dmraid/*.sh
%dir %{dracutlibdir}/modules.d/90dmsquash-live
%attr(755,root,root) %{dracutlibdir}/modules.d/90dmsquash-live/*.sh
%dir %{dracutlibdir}/modules.d/90kernel-modules
%attr(755,root,root) %{dracutlibdir}/modules.d/90kernel-modules/*.sh
%dir %{dracutlibdir}/modules.d/90lvm
%{dracutlibdir}/modules.d/90lvm/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/90lvm/*.sh
%dir %{dracutlibdir}/modules.d/90mdraid
%{dracutlibdir}/modules.d/90mdraid/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/90mdraid/*.sh
%dir %{dracutlibdir}/modules.d/90multipath
%attr(755,root,root) %{dracutlibdir}/modules.d/90multipath/*.sh
%dir %{dracutlibdir}/modules.d/90qemu
%attr(755,root,root) %{dracutlibdir}/modules.d/90qemu/*.sh
%dir %{dracutlibdir}/modules.d/91crypt-gpg
%attr(755,root,root) %{dracutlibdir}/modules.d/91crypt-gpg/*.sh
%dir %{dracutlibdir}/modules.d/95cifs
%attr(755,root,root) %{dracutlibdir}/modules.d/95cifs/*.sh
%dir %{dracutlibdir}/modules.d/95debug
%attr(755,root,root) %{dracutlibdir}/modules.d/95debug/*.sh
%dir %{dracutlibdir}/modules.d/95resume
%attr(755,root,root) %{dracutlibdir}/modules.d/95resume/*.sh
%dir %{dracutlibdir}/modules.d/95rootfs-block
%attr(755,root,root) %{dracutlibdir}/modules.d/95rootfs-block/*.sh
%dir %{dracutlibdir}/modules.d/95dasd
%attr(755,root,root) %{dracutlibdir}/modules.d/95dasd/*.sh
%dir %{dracutlibdir}/modules.d/95dasd_mod
%attr(755,root,root) %{dracutlibdir}/modules.d/95dasd_mod/*.sh
%dir %{dracutlibdir}/modules.d/95fstab-sys
%attr(755,root,root) %{dracutlibdir}/modules.d/95fstab-sys/*.sh
%dir %{dracutlibdir}/modules.d/95zfcp
%{dracutlibdir}/modules.d/95zfcp/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/95zfcp/*.sh
%dir %{dracutlibdir}/modules.d/95terminfo
%attr(755,root,root) %{dracutlibdir}/modules.d/95terminfo/*.sh
%dir %{dracutlibdir}/modules.d/95udev-rules
%{dracutlibdir}/modules.d/95udev-rules/*.rules
%attr(755,root,root) %{dracutlibdir}/modules.d/95udev-rules/*.sh
%dir %{dracutlibdir}/modules.d/95virtfs
%attr(755,root,root) %{dracutlibdir}/modules.d/95virtfs/*.sh
%dir %{dracutlibdir}/modules.d/96securityfs
%attr(755,root,root) %{dracutlibdir}/modules.d/96securityfs/*.sh
%dir %{dracutlibdir}/modules.d/97biosdevname
%attr(755,root,root) %{dracutlibdir}/modules.d/97biosdevname/*.sh
%dir %{dracutlibdir}/modules.d/97masterkey
%{dracutlibdir}/modules.d/97masterkey/README
%attr(755,root,root) %{dracutlibdir}/modules.d/97masterkey/*.sh
%dir %{dracutlibdir}/modules.d/98ecryptfs
%{dracutlibdir}/modules.d/98ecryptfs/README
%attr(755,root,root) %{dracutlibdir}/modules.d/98ecryptfs/*.sh
%dir %{dracutlibdir}/modules.d/98integrity
%{dracutlibdir}/modules.d/98integrity/README
%attr(755,root,root) %{dracutlibdir}/modules.d/98integrity/*.sh
%dir %{dracutlibdir}/modules.d/98pollcdrom
%attr(755,root,root) %{dracutlibdir}/modules.d/98pollcdrom/*.sh
%dir %{dracutlibdir}/modules.d/98selinux
%attr(755,root,root) %{dracutlibdir}/modules.d/98selinux/*.sh
%dir %{dracutlibdir}/modules.d/98syslog
%{dracutlibdir}/modules.d/98syslog/README
%{dracutlibdir}/modules.d/98syslog/rsyslog.conf
%attr(755,root,root) %{dracutlibdir}/modules.d/98syslog/*.sh
%dir %{dracutlibdir}/modules.d/98systemd
%{dracutlibdir}/modules.d/98systemd/*.service
%{dracutlibdir}/modules.d/98systemd/*.target
%attr(755,root,root) %{dracutlibdir}/modules.d/98systemd/*.sh
%doc %{dracutlibdir}/modules.d/98systemd/*.8*
%dir %{dracutlibdir}/modules.d/98usrmount
%attr(755,root,root) %{dracutlibdir}/modules.d/98usrmount/*.sh
%dir %{dracutlibdir}/modules.d/99base
%attr(755,root,root) %{dracutlibdir}/modules.d/99base/*.sh
%dir %{dracutlibdir}/modules.d/99fs-lib
%attr(755,root,root) %{dracutlibdir}/modules.d/99fs-lib/*.sh
%dir %{dracutlibdir}/modules.d/99img-lib
%attr(755,root,root) %{dracutlibdir}/modules.d/99img-lib/*.sh
%dir %{dracutlibdir}/modules.d/99shutdown
%attr(755,root,root) %{dracutlibdir}/modules.d/99shutdown/*.sh
%attr(755,root,root) %{dracutlibdir}/dracut-version.sh

%dir /var/lib/initramfs
%{systemdunitdir}/*.service
%{systemdunitdir}/*/*.service
%{_mandir}/man8/dracut.8*
%{_mandir}/man8/dracut-*.8*
%{_mandir}/man8/initrd-switch-root.service.8*
%{_mandir}/man8/udevadm-cleanup-db.service.8*
%{_mandir}/man7/dracut.kernel.7*
%{_mandir}/man7/dracut.cmdline.7*
%{_mandir}/man5/dracut.conf.5*

%files network
%defattr(644,root,root,755)
%dir %{dracutlibdir}/modules.d/40network
%{dracutlibdir}/modules.d/40network/dhclient.conf
%attr(755,root,root) %{dracutlibdir}/modules.d/40network/*.sh
%dir %{dracutlibdir}/modules.d/45ifcfg
%attr(755,root,root) %{dracutlibdir}/modules.d/45ifcfg/*.sh
%dir %{dracutlibdir}/modules.d/45url-lib
%attr(755,root,root) %{dracutlibdir}/modules.d/45url-lib/*.sh
%dir %{dracutlibdir}/modules.d/90livenet
%attr(755,root,root) %{dracutlibdir}/modules.d/90livenet/*.sh
%dir %{dracutlibdir}/modules.d/90qemu-net
%attr(755,root,root) %{dracutlibdir}/modules.d/90qemu-net/*.sh
%dir %{dracutlibdir}/modules.d/95fcoe
%attr(755,root,root) %{dracutlibdir}/modules.d/95fcoe/*.sh
%dir %{dracutlibdir}/modules.d/95iscsi
%attr(755,root,root) %{dracutlibdir}/modules.d/95iscsi/*.sh
%dir %{dracutlibdir}/modules.d/95nbd
%attr(755,root,root) %{dracutlibdir}/modules.d/95nbd/*.sh
%dir %{dracutlibdir}/modules.d/95nfs
%attr(755,root,root) %{dracutlibdir}/modules.d/95nfs/*.sh
%dir %{dracutlibdir}/modules.d/95ssh-client
%attr(755,root,root) %{dracutlibdir}/modules.d/95ssh-client/*.sh
%dir %{dracutlibdir}/modules.d/95znet
%attr(755,root,root) %{dracutlibdir}/modules.d/95znet/*.sh

%files fips
%defattr(644,root,root,755)
%dir %{dracutlibdir}/modules.d/01fips
%attr(755,root,root) %{dracutlibdir}/modules.d/01fips/*.sh
%config(noreplace) %{_sysconfdir}/dracut.conf.d/40-fips.conf

%files fips-aesni
%defattr(644,root,root,755)
%doc COPYING
%dir %{dracutlibdir}/modules.d/02fips-aesni
%attr(755,root,root) %{dracutlibdir}/modules.d/02fips-aesni/*.sh

%files caps
%defattr(644,root,root,755)
%{dracutlibdir}/modules.d/02caps/README
%dir %{dracutlibdir}/modules.d/02caps
%attr(755,root,root) %{dracutlibdir}/modules.d/02caps/*.sh

%files tools
%defattr(644,root,root,755)
%{_mandir}/man8/dracut-catimages.8*
%attr(755,root,root) %{_bindir}/dracut-catimages
%dir /boot/dracut
%dir /var/lib/dracut
%dir /var/lib/dracut/overlay
%changelog
* Thu Aug 09 2012 Jan Rękorajski <baggins@pld-linux.org> 26d6610
Updated to 023

* Thu Aug 09 2012 Jan Rękorajski <baggins@pld-linux.org> ec2adbc
Only install plymouth logo file if it exists
Release 4

* Thu Aug 09 2012 Jan Rękorajski <baggins@pld-linux.org> b87c1cd
Require vi

* Sat Jun 30 2012 Jan Rękorajski <baggins@pld-linux.org> 426980c
- rel 2
- no longer noarch due to dracut-install binary

* Sat Jun 30 2012 Jan Rękorajski <baggins@pld-linux.org> 0ba4006
- updated to 020

* Thu Jun 07 2012 Bartłomiej Zimoń <cactus@pld-linux.org> 525de25
- up to 019; with systemd support module, rpmversion module droped

* Wed May 30 2012 Jan Rękorajski <baggins@pld-linux.org> 652a87c
- rel 6
- disabled S:biosdevname

* Fri Apr 27 2012 Jan Rękorajski <baggins@pld-linux.org> 37140c4
- rel 5
- we don't have system-release, we have os-release

* Thu Apr 26 2012 Jan Rękorajski <baggins@pld-linux.org> 404f848
- rel 4
- R glibc-misc for ldd

* Mon Apr 16 2012 Jan Rękorajski <baggins@pld-linux.org> c0882d4
- rel 3
- there is no --no-wall option in SysVinit halt command, remove its use

* Sat Apr 14 2012 Jan Rękorajski <baggins@pld-linux.org> b7e4efb
- rel 2
- BR dash

* Sat Apr 14 2012 Jan Rękorajski <baggins@pld-linux.org> 8656a20
- rel 1

* Sat Apr 14 2012 Jan Rękorajski <baggins@pld-linux.org> 3b64e4b
- 018

* Sat Apr 14 2012 Jan Rękorajski <baggins@pld-linux.org> 7dbc7c4
- fixed upstream

* Mon Mar 26 2012 Jan Rękorajski <baggins@pld-linux.org> f9961ba
- rel 4
- fix dhcp-client R
- fix missing dirs

* Mon Mar 26 2012 Elan Ruusamäe <glen@pld-linux.org> 4c82305
- it's vimrc

* Thu Mar 22 2012 Elan Ruusamäe <glen@pld-linux.org> 88d9ea8
- fix plymouth libexec path

* Thu Mar 22 2012 Jan Rękorajski <baggins@pld-linux.org> 28bd8fc
- R just plain cryptsetup

* Thu Mar 22 2012 Jan Rękorajski <baggins@pld-linux.org> 707792a
- rel 2
- added some suggests and reqs
- moved url-lib to network where it belongs

* Thu Mar 22 2012 Jan Rękorajski <baggins@pld-linux.org> 801e1ba
- fix paths/names

